@@ -180,7 +180,7 @@ class ContractContainer(_ContractBase):
             i
             for i in self._contracts
             if (i.tx and i.tx.block_number is not None and i.tx.block_number > height)
-            or len(web3.eth.getCode(i.address).hex()) <= 4
+            or len(web3.eth.get_code(i.address).hex()) <= 4
         ]
         for contract in reverted:
             self.remove(contract)
@@ -745,7 +745,7 @@ class _DeployedContractBase(_ContractBase):
         self, address: str, owner: Optional[AccountsType] = None, tx: TransactionReceiptType = None
     ) -> None:
         address = _resolve_address(address)
-        self.bytecode = web3.eth.getCode(address).hex()[2:]
+        self.bytecode = web3.eth.get_code(address).hex()[2:]
         if not self.bytecode:
             raise ContractNotFound(f"No contract deployed at {address}")
         self._owner = owner
@@ -778,9 +778,10 @@ class _DeployedContractBase(_ContractBase):
         if name == "balance":
             warnings.warn(
                 f"'{self._name}' defines a 'balance' function, "
-                f"'{self._name}.balance' is unavailable",
+                f"'{self._name}.balance' is available as {self._name}.wei_balance",
                 BrownieEnvironmentWarning,
             )
+            setattr(self, "wei_balance", self.balance)
         elif hasattr(self, name):
             warnings.warn(
                 "Namespace collision between contract function and "
@@ -788,8 +789,8 @@ class _DeployedContractBase(_ContractBase):
                 f"The {name} function will not be available when interacting with {self._name}",
                 BrownieEnvironmentWarning,
             )
-        else:
-            setattr(self, name, obj)
+            return
+        setattr(self, name, obj)
 
     def __hash__(self) -> int:
         return hash(f"{self._name}{self.address}{self._project}")
@@ -844,7 +845,7 @@ class _DeployedContractBase(_ContractBase):
 
     def balance(self) -> Wei:
         """Returns the current ether balance of the contract, in wei."""
-        balance = web3.eth.getBalance(self.address)
+        balance = web3.eth.get_balance(self.address)
         return Wei(balance)
 
     def _deployment_path(self) -> Optional[Path]:
@@ -866,7 +867,7 @@ class _DeployedContractBase(_ContractBase):
         deployment_build["deployment"] = {
             "address": self.address,
             "chainid": chainid,
-            "blockHeight": web3.eth.blockNumber,
+            "blockHeight": web3.eth.block_number,
         }
         if path:
             self._project._add_to_deployment_map(self)
@@ -1109,11 +1110,11 @@ class Contract(_DeployedContractBase):
 
         if as_proxy_for is None:
             # always check for an EIP1967 proxy - https://eips.ethereum.org/EIPS/eip-1967
-            implementation_eip1967 = web3.eth.getStorageAt(
+            implementation_eip1967 = web3.eth.get_storage_at(
                 address, int(web3.keccak(text="eip1967.proxy.implementation").hex(), 16) - 1
             )
             # always check for an EIP1822 proxy - https://eips.ethereum.org/EIPS/eip-1822
-            implementation_eip1822 = web3.eth.getStorageAt(address, web3.keccak(text="PROXIABLE"))
+            implementation_eip1822 = web3.eth.get_storage_at(address, web3.keccak(text="PROXIABLE"))
             if len(implementation_eip1967) > 0 and int(implementation_eip1967.hex(), 16):
                 as_proxy_for = _resolve_address(implementation_eip1967[-20:])
             elif len(implementation_eip1822) > 0 and int(implementation_eip1822.hex(), 16):
@@ -1790,7 +1791,7 @@ def _inputs(abi: Dict) -> str:
 
 
 def _verify_deployed_code(address: str, expected_bytecode: str, language: str) -> bool:
-    actual_bytecode = web3.eth.getCode(address).hex()[2:]
+    actual_bytecode = web3.eth.get_code(address).hex()[2:]
     expected_bytecode = remove_0x_prefix(expected_bytecode)  # type: ignore
 
     if expected_bytecode.startswith("730000000000000000000000000000000000000000"):
@@ -1845,7 +1846,7 @@ def _fetch_from_explorer(address: str, action: str, silent: bool) -> Dict:
     if address in _unverified_addresses:
         raise ValueError(f"Source for {address} has not been verified")
 
-    code = web3.eth.getCode(address).hex()[2:]
+    code = web3.eth.get_code(address).hex()[2:]
     # EIP-1167: Minimal Proxy Contract
     if code[:20] == "363d3d373d3d3d363d73" and code[60:] == "5af43d82803e903d91602b57fd5bf3":
         address = _resolve_address(code[20:60])
@@ -1857,7 +1858,7 @@ def _fetch_from_explorer(address: str, action: str, silent: bool) -> Dict:
         address = _resolve_address(code[30:70])
 
     params: Dict = {"module": "contract", "action": action, "address": address}
-    if "etherscan" in url or "bscscan" in url:
+    if "etherscan" in url:
         if os.getenv("ETHERSCAN_TOKEN"):
             params["apiKey"] = os.getenv("ETHERSCAN_TOKEN")
         elif not silent:
@@ -1867,6 +1868,16 @@ def _fetch_from_explorer(address: str, action: str, silent: bool) -> Dict:
                 "as the environment variable $ETHERSCAN_TOKEN",
                 BrownieEnvironmentWarning,
             )
+    elif "bscscan" in url:
+        if os.getenv("BSCSCAN_TOKEN"):
+            params["apiKey"] = os.getenv("BSCSCAN_TOKEN")
+        elif not silent:
+            warnings.warn(
+                "No BSCScan API token set. You may experience issues with rate limiting. "
+                "Visit https://bscscan.com/register to obtain a token, and then store it "
+                "as the environment variable $BSCSCAN_TOKEN",
+                BrownieEnvironmentWarning,
+            )
 
     if not silent:
         print(
@@ -1879,7 +1890,7 @@ def _fetch_from_explorer(address: str, action: str, silent: bool) -> Dict:
         raise ConnectionError(f"Status {response.status_code} when querying {url}: {response.text}")
     data = response.json()
     if int(data["status"]) != 1:
-        raise ValueError(f"Failed to retrieve data from API: {data['result']}")
+        raise ValueError(f"Failed to retrieve data from API: {data}")
 
     return data
 
