@@ -17,7 +17,7 @@ from web3.exceptions import TimeExhausted, TransactionNotFound
 
 from brownie._config import CONFIG
 from brownie.convert import EthAddress, Wei
-from brownie.exceptions import RPCRequestError
+from brownie.exceptions import ContractNotFound, RPCRequestError
 from brownie.project import build
 from brownie.project import main as project_main
 from brownie.project.compiler.solidity import SOLIDITY_ERROR_CODES
@@ -283,13 +283,13 @@ class TransactionReceipt:
     def timestamp(self) -> Optional[int]:
         if self.status < 0:
             return None
-        return web3.eth.getBlock(self.block_number)["timestamp"]
+        return web3.eth.get_block(self.block_number)["timestamp"]
 
     @property
     def confirmations(self) -> int:
         if not self.block_number:
             return 0
-        return web3.eth.blockNumber - self.block_number + 1
+        return web3.eth.block_number - self.block_number + 1
 
     def replace(
         self,
@@ -361,11 +361,11 @@ class TransactionReceipt:
 
         while True:
             try:
-                tx: Dict = web3.eth.getTransaction(self.txid)
+                tx: Dict = web3.eth.get_transaction(self.txid)
                 break
             except TransactionNotFound:
                 if self.nonce is not None:
-                    sender_nonce = web3.eth.getTransactionCount(str(self.sender))
+                    sender_nonce = web3.eth.get_transaction_count(str(self.sender))
                     if sender_nonce > self.nonce:
                         self.status = Status(-2)
                         self._confirmed.set()
@@ -398,7 +398,7 @@ class TransactionReceipt:
         # await tx showing in mempool
         while True:
             try:
-                tx: Dict = web3.eth.getTransaction(HexBytes(self.txid))
+                tx: Dict = web3.eth.get_transaction(HexBytes(self.txid))
                 break
             except (TransactionNotFound, ValueError):
                 if self.sender is None:
@@ -406,7 +406,7 @@ class TransactionReceipt:
                     # not broadcasted locally and so likely doesn't exist
                     raise
                 if self.nonce is not None:
-                    sender_nonce = web3.eth.getTransactionCount(str(self.sender))
+                    sender_nonce = web3.eth.get_transaction_count(str(self.sender))
                     if sender_nonce > self.nonce:
                         self.status = Status(-2)
                         return
@@ -444,10 +444,10 @@ class TransactionReceipt:
         # await first confirmation
         while True:
             # if sender nonce is greater than tx nonce, the tx should be confirmed
-            sender_nonce = web3.eth.getTransactionCount(str(self.sender))
+            sender_nonce = web3.eth.get_transaction_count(str(self.sender))
             expect_confirmed = bool(sender_nonce > self.nonce)  # type: ignore
             try:
-                receipt = web3.eth.waitForTransactionReceipt(
+                receipt = web3.eth.wait_for_transaction_receipt(
                     HexBytes(self.txid), timeout=15, poll_latency=1
                 )
                 break
@@ -463,14 +463,14 @@ class TransactionReceipt:
         remaining_confs = required_confs
         while remaining_confs > 0 and required_confs > 1:
             try:
-                receipt = web3.eth.getTransactionReceipt(self.txid)
+                receipt = web3.eth.get_transaction_receipt(self.txid)
                 self.block_number = receipt["blockNumber"]
             except TransactionNotFound:
                 if not self._silent:
                     sys.stdout.write(f"\r{color('red')}Transaction was lost...{color}{' ' * 8}")
                     sys.stdout.flush()
                 # check if tx is still in mempool, this will raise otherwise
-                tx = web3.eth.getTransaction(self.txid)
+                tx = web3.eth.get_transaction(self.txid)
                 self.block_number = None
                 return self._await_confirmation(tx["blockNumber"], required_confs)
             if required_confs - self.confirmations != remaining_confs:
@@ -516,10 +516,18 @@ class TransactionReceipt:
         self.nonce = tx["nonce"]
 
         # if receiver is a known contract, set function name
-        if not self.fn_name and state._find_contract(tx["to"]) is not None:
+        if self.fn_name:
+            return
+        try:
             contract = state._find_contract(tx["to"])
-            self.contract_name = contract._name
-            self.fn_name = contract.get_method(tx["input"])
+            if contract is not None:
+                self.contract_name = contract._name
+                self.fn_name = contract.get_method(tx["input"])
+        except ContractNotFound:
+            # required in case the contract has self destructed
+            # other aspects of functionality will be broken, but this way we
+            # can at least return a receipt
+            pass
 
     def _set_from_receipt(self, receipt: Dict) -> None:
         """Sets object attributes based on the transaction reciept."""
@@ -540,7 +548,7 @@ class TransactionReceipt:
         self.coverage_hash = sha1(base.encode()).hexdigest()
 
         if self.fn_name:
-            state.TxHistory()._gas(self._full_name(), receipt["gasUsed"])
+            state.TxHistory()._gas(self._full_name(), receipt["gasUsed"], self.status == Status(1))
 
     def _confirm_output(self) -> str:
         status = ""
@@ -620,7 +628,7 @@ class TransactionReceipt:
             fn = contract.get_method_object(self.input)
             self._return_value = fn.decode_output(data)
 
-    def _reverted_trace(self, trace: Sequence,) -> None:
+    def _reverted_trace(self, trace: Sequence) -> None:
         self._modified_state = False
         if self.contract_address:
             step = next((i for i in trace if i["op"] == "CODECOPY"), None)
@@ -716,8 +724,8 @@ class TransactionReceipt:
                     self._dev_revert_msg = ""
                 return
 
-        step = next(i for i in trace[::-1] if i["op"] in ("REVERT", "INVALID"))
-        self._revert_msg = "invalid opcode" if step["op"] == "INVALID" else ""
+        op = next((i["op"] for i in trace[::-1] if i["op"] in ("REVERT", "INVALID")), None)
+        self._revert_msg = "invalid opcode" if op == "INVALID" else ""
 
     def _expand_trace(self) -> None:
         """Adds the following attributes to each step of the stack trace:
@@ -1101,7 +1109,10 @@ class TransactionReceipt:
         except StopIteration:
             return ""
 
-        result = [next(i for i in trace_range if trace[i]["source"])]
+        try:
+            result = [next(i for i in trace_range if trace[i]["source"])]
+        except StopIteration:
+            return ""
         depth, jump_depth = trace[idx]["depth"], trace[idx]["jumpDepth"]
 
         while True:
